Function intrinsic_point

pub fn intrinsic_point(curve: &Intrinsic2, s: f64) -> Result<DVec2, GeomError>
Position on an intrinsic curve at arc length s from its start.

The heading is exact; the position is Gauss-Legendre quadrature of the unit tangent, which is where the non-elementary integral is discharged.