Function orient_arc_ring

pub fn orient_arc_ring(
    ring: &ArcRing,
    counter_clockwise: bool,
) -> Result<ArcRing, GeomError>
Force a ring to the winding a boundary role requires.

Outer boundaries run counter-clockwise and holes run clockwise, so that a ring’s wall normals point out of the material in both cases.