pub struct EmbeddedFaceCurve {
pub face: FaceId,
pub edge: EdgeId,
pub pcurve: Curve2Id,
pub interval: Interval,
}Expand description
A certified edge embedded in a face without pretending it is a closed trim.
Fields
face: FaceIdUnsplit face that contains the intersection chord.
edge: EdgeIdShared model-space intersection edge.
pcurve: Curve2IdSurface-parameter image from edge start to edge end.
interval: IntervalNative pcurve interval, oriented from edge start to edge end.