Struct DistanceBounds
pub struct DistanceBounds {
pub lower: f64,
pub upper: f64,
pub point_a: DVec3,
pub point_b: DVec3,
}Expand description
An interval certain to contain the distance between two boundaries.
Fields
lower: f64No two boundary points are closer than this.
upper: f64point_a and point_b are this far apart.
point_a: DVec3A point on the first boundary.
point_b: DVec3A point on the second boundary, upper from point_a.
Implementations
impl DistanceBounds
impl DistanceBounds