#[non_exhaustive]pub enum MeshValidationError {
IncompleteTriangle {
index_count: usize,
},
PositionIndexOutOfRange {
index: u32,
position_count: usize,
},
NormalCount {
expected: usize,
actual: usize,
},
NormalIndexCount {
expected: usize,
actual: usize,
},
NormalIndexOutOfRange {
index: u32,
normal_count: usize,
},
AttributeCount {
name: String,
expected: usize,
actual: usize,
},
AttributeZeroWidth {
name: String,
},
AttributeDuplicateName {
name: String,
},
AttributeRaggedValues {
name: String,
values: usize,
width: usize,
},
AttributeCornerCount {
name: String,
expected: usize,
actual: usize,
},
AttributeCornerIndexOutOfRange {
name: String,
index: u32,
value_count: usize,
},
AttributePartiallyMapped {
name: String,
triangle: usize,
},
}Expand description
Cheap structural validation failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IncompleteTriangle
Triangle index buffer is not divisible by three.
PositionIndexOutOfRange
Position index does not exist.
NormalCount
Non-indexed normals do not align with positions.
NormalIndexCount
Independently indexed normals do not align with corners.
NormalIndexOutOfRange
Normal index does not exist.
AttributeCount
A channel does not carry one tuple per vertex.
Fields
AttributeZeroWidth
A channel declares a zero tuple width, which covers no vertices.
AttributeDuplicateName
Two channels share a name, so a lookup would be ambiguous.
AttributeRaggedValues
A corner-indexed channel’s values is not whole tuples.
AttributeCornerCount
A corner-indexed channel does not have one entry per triangle corner.
Fields
AttributeCornerIndexOutOfRange
A corner index points past the channel’s values.
Fields
AttributePartiallyMapped
A triangle has some corners mapped and some unmapped.