Trait MeshView

pub trait MeshView {
    // Required methods
    fn positions(&self) -> &[DVec3];
    fn indices(&self) -> &[u32];
}
Read-only triangle mesh view.

A foreign kernel can implement this for its native mesh and call algorithms without first adopting Axiolid’s owned container.

Required Methods

fn positions(&self) -> &[DVec3]

Position buffer.

fn indices(&self) -> &[u32]

Triangle corner index buffer.

Implementors