Trait BuiltInNode

pub trait BuiltInNode: Sealed + Into<GeometryNode> { }
A built-in neutral value that can be inserted into a crate::GeometryGraph.

This is sealed deliberately. Third-party kernels extend execution through the open traits in operation-contract packages; source adapters extend input by translating their values into one of the canonical node families.

ⓘ
use axiolid_model::{BuiltInNode, GeometryNode};

struct ForeignNode;

impl Into<GeometryNode> for ForeignNode {
    fn into(self) -> GeometryNode {
        panic!("compile-only example")
    }
}

// Rejected because the private sealing trait cannot be implemented here.
impl BuiltInNode for ForeignNode {}

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl BuiltInNode for DAffine3

Implementors