Function extract_stretch

pub fn extract_stretch(
    curves: &[ImplicitCurve2],
    periodic: (bool, bool),
    start: DVec2,
    _: [DVec2; 2],
    end: DVec2,
    closed: bool,
) -> Option<ImplicitCurve2>
The stretch of one of curves that runs from start through first and then second to end (all in parameters, each possibly a whole period off), as a curve of its own running from start to end. closed asks for a whole loop from start back to itself, in the direction that meets first before second.