Struct ExactCurveHit
#[non_exhaustive]pub struct ExactCurveHit {
pub parameter: ExactCurveParameter,
pub multiplicity: usize,
pub point: DVec3,
}Expand description
One intersection point.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parameter: ExactCurveParameterIts parameter on the first curve, exactly.
multiplicity: usizeIts multiplicity: 1 for a transverse crossing, 2 or more where the curve touches the other operand.
point: DVec3The point, rounded from the curve at the parameter (output only).
Planar results have z = 0.
Implementations
impl ExactCurveHit
impl ExactCurveHit
pub fn is_tangent(&self) -> bool
pub fn is_tangent(&self) -> bool
Whether the curve touches rather than crosses here.