Struct FundamentalForm
pub struct FundamentalForm {
pub e: f64,
pub f: f64,
pub g: f64,
}Expand description
Coefficients (e, f, g) of a quadratic fundamental form.
Fields
e: f64First diagonal coefficient (E for the first form, e for the second).
f: f64Mixed coefficient (F for the first form, f for the second).
g: f64Second diagonal coefficient (G for the first form, g for the second).