pub struct OrientedRectangle {
pub centre: DVec2,
pub axes: [DVec2; 2],
pub half_extents: [f64; 2],
}Expand description
A rectangle by its centre, two unit axes and the half extents along them.
Fields
centre: DVec2Centre.
axes: [DVec2; 2]Unit axes, counter-clockwise: the second is the first turned a
quarter. The first points into [0, 90) degrees.
half_extents: [f64; 2]Half the side lengths along the axes; one is zero for collinear input, both for a single point.
Implementations