#[non_exhaustive]pub enum SkeletonError {
Route(RouteError),
InvalidParameter,
Triangulation,
}Expand description
Why no skeleton was built.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Route(RouteError)
The region is malformed, or a predicate was undecidable.
InvalidParameter
The spacing or prune factor is not positive and finite.
Triangulation
The boundary could not be triangulated: rings cross.