Function distance_map

pub fn distance_map(
    region: &[Polygon],
    barriers: &[Vec<DVec2>],
    targets: &[DVec2],
) -> Result<DistanceMap, MapError>
A distance map from targets over region, avoiding barriers.

Errors

MapError for malformed input, no targets, a target outside the region, or more than MAX_VERTICES graph vertices.