#[non_exhaustive]pub struct Farthest {
pub distance: LengthInterval,
pub witness: Option<DVec2>,
pub converged: bool,
pub cells: usize,
}Expand description
The greatest distance from a subregion to the nearest target.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.distance: LengthIntervalContains the true maximum over the subregion’s points in the free space.
witness: Option<DVec2>A point of the subregion, in the free space, at least
distance.lower from every target; None only when the budget ran
out before any point of the subregion was sampled.
converged: boolWhether the interval is no wider than the tolerance asked for. When the cell budget runs out first it is still sound, only wider.
cells: usizeCells examined.