pub struct BRep<Curve3, Curve2 = Curve3, Surface = Curve3> { /* private fields */ }Expand description
Owned B-rep. Generic geometry handles avoid a dependency cycle with the model graph that stores exact curves and surfaces.
Implementations
Sourceimpl<Curve3, Curve2, Surface> BRep<Curve3, Curve2, Surface>
impl<Curve3, Curve2, Surface> BRep<Curve3, Curve2, Surface>
Sourcepub fn try_reserve(
&mut self,
vertices: usize,
edges: usize,
loops: usize,
faces: usize,
shells: usize,
solids: usize,
) -> Result<(), TryReserveError>
pub fn try_reserve( &mut self, vertices: usize, edges: usize, loops: usize, faces: usize, shells: usize, solids: usize, ) -> Result<(), TryReserveError>
Fallibly reserve append-only arena capacity for bounded construction.
Sourcepub fn add_vertex(&mut self, value: Vertex) -> VertexId
pub fn add_vertex(&mut self, value: Vertex) -> VertexId
Add a vertex and return its typed handle.
Sourcepub fn add_edge(&mut self, value: Edge<Curve3>) -> EdgeId
pub fn add_edge(&mut self, value: Edge<Curve3>) -> EdgeId
Add an edge and return its typed handle.
Sourcepub fn add_loop(&mut self, value: Loop<Curve2>) -> LoopId
pub fn add_loop(&mut self, value: Loop<Curve2>) -> LoopId
Add a loop and return its typed handle.
Sourcepub fn add_face(&mut self, value: Face<Surface>) -> FaceId
pub fn add_face(&mut self, value: Face<Surface>) -> FaceId
Add a face and return its typed handle.
Sourcepub fn edge_id_at(&self, index: usize) -> Option<EdgeId>
pub fn edge_id_at(&self, index: usize) -> Option<EdgeId>
Edge handle at a dense arena index, if present.
Sourcepub fn loop_id_at(&self, index: usize) -> Option<LoopId>
pub fn loop_id_at(&self, index: usize) -> Option<LoopId>
Loop handle at a dense arena index, if present.
Sourcepub fn face_id_at(&self, index: usize) -> Option<FaceId>
pub fn face_id_at(&self, index: usize) -> Option<FaceId>
Face handle at a dense arena index, if present.