pub fn tapered_revolve(
start: &Rings,
end: &Rings,
axis_origin: DVec3,
axis_direction: DVec3,
angle: f64,
tolerance: Tolerance,
) -> Result<TriMesh, GeomError>Expand description
Revolve between two profiles.
Unlike a plain revolution this can never close: a full turn would have to meet the start profile with the end profile, which are different by construction. It is always capped.